@@ -1,12 +1,14 @@
 package DBIx::Handler;
 use strict;
 use warnings;
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use DBI 1.605;
 use DBIx::TransactionManager 1.09;
 use Carp ();
 
+our $TxnTraceLevel = 0;
+
 sub _noop {}
 
 *connect = \&new;
@@ -246,15 +248,15 @@ sub _in_txn_check {
 }
 
 sub txn_scope {
-    my @caller = caller();
-    $_[0]->txn_manager->txn_scope(caller => \@caller);
+    my @caller = caller($TxnTraceLevel);
+    shift->txn_manager->txn_scope(caller => \@caller, @_);
 }
 
 sub txn {
     my ($self, $coderef) = @_;
 
     my $wantarray = wantarray;
-    my $txn = $self->txn_scope;
+    my $txn = $self->txn_scope(caller => [caller($TxnTraceLevel)]);
 
     my @ret = eval {
         my $dbh = $self->dbh;
